==> crud_service-0.1.6.tar.gz: lib/Service/BaseService.dart <==

import 'dart:convert';
import 'package:crud_service/crud_service.dart';
import 'package:dio/dio.dart';
import 'package:crud_service/Model/RequestC.dart';
import 'package:crud_service/Model/RequestD.dart';
import 'package:crud_service/Env/ServiceConfig.dart';
import 'package:crud_service/Model/crud_entity.dart';
import 'package:crud_service/Model/request_entity.dart';

class BaseService<T extends CrudEntity> {
  static Dio dio = new Dio(BaseOptions(baseUrl: ServiceConfig.shared.baseUrl()));
  static JsonCodec json = const JsonCodec();
  RequestPage responsePage;

  Future<dynamic> post(String path, RequestEntity data) async {

    RequestFilter st = RequestFilter(CRUDOperator.NE, "st", 9);
    if (data.d.filters == null) {
      data.d.filters = [st];
    } else {
      data.d.filters.add(st);
    }
    print("path:" + path);
    print("request:" + json.encode(data.toJson()));
    var r = await BaseService.dio.post(path, data: data.toJson());
    var responseData = r.data;
    if (responseData is String) {
      print("response:" + responseData);
      Map<String, dynamic> jsonData = json.decode(responseData);
      var resultJson = jsonData["result"];
      deserilizerPage(jsonData);
      return resultJson;
    } else {
      print("response:" + json.encode(responseData));
      var resultJson = responseData["result"];
      deserilizerPage(responseData);
      return resultJson;
    }
  }

  void deserilizerPage(Map<String, dynamic> jsonData) {
    if (jsonData["page"] != null && jsonData["page"] is Map<String, dynamic>) {
      responsePage = RequestPage.deserilizer(jsonData["page"]);
    }
  }

  Future<RequestEntity> createRequest() async {
    var request = RequestEntity();

    var requestD = RequestD();
    request.d = requestD;

    List<RequestC> cArray = new List<RequestC>();
    var parameter = ServiceConfig.shared.commonParameter;
    for (String key in parameter.keys) {
      var value = parameter[key];
      cArray.add(RequestC(key, value));
    }
    requestD.c = cArray;
    return request;
  }
}

==> crud_service-0.1.9.tar.gz: lib/Service/BaseService.dart <==

import 'dart:convert';
import 'package:crud_service/Exception/ErrorException.dart';
import 'package:crud_service/crud_service.dart';
import 'package:dio/dio.dart';
import 'package:crud_service/Model/RequestC.dart';
import 'package:crud_service/Model/RequestD.dart';
import 'package:crud_service/Env/ServiceConfig.dart';
import 'package:crud_service/Model/crud_entity.dart';
import 'package:crud_service/Model/request_entity.dart';

class BaseService<T extends CrudEntity> {
  static Dio dio = new Dio(BaseOptions(baseUrl: ServiceConfig.shared.baseUrl()));
  static JsonCodec json = const JsonCodec();
  RequestPage responsePage;

  Future<dynamic> post(String path, RequestEntity data) async {
    RequestFilter st = RequestFilter(CRUDOperator.NE, "st", 9);
    if (data.d.filters == null) {
      data.d.filters = [st];
    } else {
      data.d.filters.add(st);
    }
    print("path:" + path);
    print("request:" + json.encode(data.toJson()));
    try {
      Response response = await BaseService.dio.post(path, data: data.toJson());
      var responseData = response.data;
      if (responseData is String) {
        print("response:" + responseData);
        Map<String, dynamic> jsonData = json.decode(responseData);
        var resultJson = jsonData["result"];
        deserilizerPage(jsonData);
        return resultJson;
      } else {
        print("response:" + json.encode(responseData));
        var resultJson = responseData["result"];
        deserilizerPage(responseData);
        return resultJson;
      }
    } on DioError catch (e) {
      Map<String, dynamic> jsonData;
      if(e.response !=null) {
        jsonData = json.decode(e.response.toString());
      }
      throw new ErrorException(jsonData);
    }
  }

  void deserilizerPage(Map<String, dynamic> jsonData) {
    if (jsonData["page"] != null && jsonData["page"] is Map<String, dynamic>) {
      responsePage = RequestPage.deserilizer(jsonData["page"]);
    }
  }

  Future<RequestEntity> createRequest() async {
    var request = RequestEntity();

    var requestD = RequestD();
    request.d = requestD;

    List<RequestC> cArray = new List<RequestC>();
    var parameter = ServiceConfig.shared.commonParameter;
    for (String key in parameter.keys) {
      var value = parameter[key];
      cArray.add(RequestC(key, value));
    }
    requestD.c = cArray;
    return request;
  }


}
